package com.mysql.jdbc;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.KeyManagementException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.sql.SQLException;
import javax.net.ssl.KeyManagerFactory;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManagerFactory;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/ExportControlled.class */
public class ExportControlled {
    private static final String SQL_STATE_BAD_SSL_PARAMS = "08000";

    /* JADX INFO: Access modifiers changed from: protected */
    public static boolean enabled() {
        return true;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void transformSocketToSSLSocket(MysqlIO mysqlIO) throws SQLException {
        SSLSocketFactory sslFact = getSSLSocketFactoryDefaultOrConfigured(mysqlIO);
        try {
            mysqlIO.mysqlConnection = sslFact.createSocket(mysqlIO.mysqlConnection, mysqlIO.host, mysqlIO.port, true);
            ((SSLSocket) mysqlIO.mysqlConnection).setEnabledProtocols(new String[]{"TLSv1"});
            ((SSLSocket) mysqlIO.mysqlConnection).startHandshake();
            if (mysqlIO.connection.getUseUnbufferedInput()) {
                mysqlIO.mysqlInput = mysqlIO.mysqlConnection.getInputStream();
            } else {
                mysqlIO.mysqlInput = new BufferedInputStream(mysqlIO.mysqlConnection.getInputStream(), 16384);
            }
            mysqlIO.mysqlOutput = new BufferedOutputStream(mysqlIO.mysqlConnection.getOutputStream(), 16384);
            mysqlIO.mysqlOutput.flush();
        } catch (IOException ioEx) {
            throw SQLError.createCommunicationsException(mysqlIO.connection, mysqlIO.lastPacketSentTimeMs, ioEx);
        }
    }

    private ExportControlled() {
    }

    private static SSLSocketFactory getSSLSocketFactoryDefaultOrConfigured(MysqlIO mysqlIO) throws SQLException {
        String clientCertificateKeyStoreUrl = mysqlIO.connection.getClientCertificateKeyStoreUrl();
        String trustCertificateKeyStoreUrl = mysqlIO.connection.getTrustCertificateKeyStoreUrl();
        String clientCertificateKeyStoreType = mysqlIO.connection.getClientCertificateKeyStoreType();
        String clientCertificateKeyStorePassword = mysqlIO.connection.getClientCertificateKeyStorePassword();
        String trustCertificateKeyStoreType = mysqlIO.connection.getTrustCertificateKeyStoreType();
        String trustCertificateKeyStorePassword = mysqlIO.connection.getTrustCertificateKeyStorePassword();
        if (StringUtils.isNullOrEmpty(clientCertificateKeyStoreUrl) && StringUtils.isNullOrEmpty(trustCertificateKeyStoreUrl)) {
            return (SSLSocketFactory) SSLSocketFactory.getDefault();
        }
        try {
            TrustManagerFactory tmf = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
            KeyManagerFactory kmf = KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
            if (StringUtils.isNullOrEmpty(clientCertificateKeyStoreUrl)) {
                try {
                    KeyStore clientKeyStore = KeyStore.getInstance(clientCertificateKeyStoreType);
                    URL ksURL = new URL(clientCertificateKeyStoreUrl);
                    char[] password = clientCertificateKeyStorePassword == null ? new char[0] : clientCertificateKeyStorePassword.toCharArray();
                    clientKeyStore.load(ksURL.openStream(), password);
                    kmf.init(clientKeyStore, password);
                } catch (MalformedURLException e) {
                    throw SQLError.createSQLException(new StringBuffer().append(clientCertificateKeyStoreUrl).append(" does not appear to be a valid URL.").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (IOException ioe) {
                    throw SQLError.createSQLException(new StringBuffer().append("Cannot open ").append(clientCertificateKeyStoreUrl).append(" [").append(ioe.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (KeyStoreException kse) {
                    throw SQLError.createSQLException(new StringBuffer().append("Could not create KeyStore instance [").append(kse.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (NoSuchAlgorithmException nsae) {
                    throw SQLError.createSQLException(new StringBuffer().append("Unsupported keystore algorithm [").append(nsae.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (UnrecoverableKeyException e2) {
                    throw SQLError.createSQLException("Could not recover keys from client keystore.  Check password?", SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (CertificateException e3) {
                    throw SQLError.createSQLException(new StringBuffer().append("Could not load client").append(clientCertificateKeyStoreType).append(" keystore from ").append(clientCertificateKeyStoreUrl).toString());
                }
            }
            if (StringUtils.isNullOrEmpty(trustCertificateKeyStoreUrl)) {
                try {
                    KeyStore trustKeyStore = KeyStore.getInstance(trustCertificateKeyStoreType);
                    URL ksURL2 = new URL(trustCertificateKeyStoreUrl);
                    trustKeyStore.load(ksURL2.openStream(), trustCertificateKeyStorePassword == null ? new char[0] : trustCertificateKeyStorePassword.toCharArray());
                    tmf.init(trustKeyStore);
                } catch (MalformedURLException e4) {
                    throw SQLError.createSQLException(new StringBuffer().append(trustCertificateKeyStoreUrl).append(" does not appear to be a valid URL.").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (IOException ioe2) {
                    throw SQLError.createSQLException(new StringBuffer().append("Cannot open ").append(trustCertificateKeyStoreUrl).append(" [").append(ioe2.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (KeyStoreException kse2) {
                    throw SQLError.createSQLException(new StringBuffer().append("Could not create KeyStore instance [").append(kse2.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (NoSuchAlgorithmException nsae2) {
                    throw SQLError.createSQLException(new StringBuffer().append("Unsupported keystore algorithm [").append(nsae2.getMessage()).append("]").toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                } catch (CertificateException e5) {
                    throw SQLError.createSQLException(new StringBuffer().append("Could not load trust").append(trustCertificateKeyStoreType).append(" keystore from ").append(trustCertificateKeyStoreUrl).toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
                }
            }
            try {
                SSLContext sslContext = SSLContext.getInstance("TLS");
                sslContext.init(kmf.getKeyManagers(), tmf.getTrustManagers(), null);
                return sslContext.getSocketFactory();
            } catch (KeyManagementException kme) {
                throw SQLError.createSQLException(new StringBuffer().append("KeyManagementException: ").append(kme.getMessage()).toString(), SQL_STATE_BAD_SSL_PARAMS, 0, false);
            } catch (NoSuchAlgorithmException e6) {
                throw SQLError.createSQLException("TLS is not a valid SSL protocol.", SQL_STATE_BAD_SSL_PARAMS, 0, false);
            }
        } catch (NoSuchAlgorithmException e7) {
            throw SQLError.createSQLException("Default algorithm definitions for TrustManager and/or KeyManager are invalid.  Check java security properties file.", SQL_STATE_BAD_SSL_PARAMS, 0, false);
        }
    }
}
